@@ -57,9 +57,11 @@ from actionlib_msgs.msg import GoalStatus
 class AXClientApp(wx.App):
     def __init__(self, action_type, action_name):
         self.action_type = action_type
+        self.action_name = action_name
         wx.App.__init__(self)
 
-        self.client = actionlib.SimpleActionClient(action_name, self.action_type.action)
+        self.client = actionlib.SimpleActionClient(
+            self.action_name, self.action_type.action)
         self.condition = threading.Condition()
         self.goal_msg = None
         self.execute_type = None
@@ -156,7 +158,10 @@ class AXClientApp(wx.App):
 
     def OnInit(self):
 
-        self.frame = wx.Frame(None, -1, self.action_type.name + ' GUI Client')
+        self.frame = wx.Frame(
+            None, -1,
+            self.action_name + ' - ' + self.action_type.name + ' - GUI Client'
+        )
 
         self.sz = wx.BoxSizer(wx.VERTICAL)
 
